import "./tasks/mapping.wdl" as mapping
import "./tasks/SamToBam.wdl" as SamToBam
import "./tasks/indexBam.wdl" as indexBam
import "./tasks/Metrics.wdl" as Metrics
import "./tasks/Dedup.wdl" as Dedup
import "./tasks/deduped_Metrics.wdl" as deduped_Metrics
import "./tasks/SplitReads.wdl" as SplitReads
import "./tasks/BQSR.wdl" as BQSR
import "./tasks/Haplotyper.wdl" as Haplotyper
import "./tasks/Hardfiltration.wdl" as Hardfiltration

workflow {{ project_name }} {

	File fastq_1
	File fastq_2
	File SAref_dir
	File STref_dir
	File dbsnp_dir
	File dbsnp
	File dbmills_dir
	File db_mills

	String SENTIEON_INSTALL_DIR
	String sample
	String STdocker
	String SAMdocker
	String SAdocker
	String PIdocker
	String GATKdocker
	String fasta
	String disk_size
	String cluster_config

	String id
	String library
	String platform
	String machine


	call mapping.mapping as mapping {
		input: 
		SAref_dir=SAref_dir,
		STref_dir=STref_dir,
		sample=sample,
		fasta=fasta,
		fastq_1=fastq_1,
		fastq_2=fastq_2,
		SAdocker=SAdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call SamToBam.SamToBam as SamToBam {
		input:
		aligned_sam=mapping.aligned_sam,
		sample=sample,
		id=id,
		library=library,
		platform=platform,
		machine=machine, 
		PIdocker=PIdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call indexBam.indexBam as indexBam {
		input: 
		sample=sample,
		sorted_bam=SamToBam.sorted_bam,
		SAMdocker=SAMdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Metrics.Metrics as Metrics {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		STref_dir=STref_dir,
		sorted_bam=SamToBam.sorted_bam,
		sorted_bam_index=indexBam.sorted_bam_index,		
		sample=sample,
		STdocker=STdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Dedup.Dedup as Dedup {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		sorted_bam=SamToBam.sorted_bam,
		sorted_bam_index=indexBam.sorted_bam_index,		
		sample=sample,
		STdocker=STdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call deduped_Metrics.deduped_Metrics as deduped_Metrics {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		STref_dir=STref_dir,
		Dedup_bam=Dedup.Dedup_bam,
		Dedup_bam_index=Dedup.Dedup_bam_index,
		sample=sample,
		STdocker=STdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call SplitReads.SplitReads as SplitReads {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		STref_dir=STref_dir,
		Dedup_bam=Dedup.Dedup_bam,
		Dedup_bam_index=Dedup.Dedup_bam_index,
		sample=sample,
		STdocker=STdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}
	
	call BQSR.BQSR as BQSR {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		dbsnp_dir=dbsnp_dir,
		dbsnp=dbsnp,
		dbmills_dir=dbmills_dir,
		db_mills=db_mills,
		STref_dir=STref_dir,
		Split_bam=SplitReads.Split_bam,
		Split_bam_index=SplitReads.Split_bam_index,
		sample=sample,
		STdocker=STdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Haplotyper.Haplotyper as Haplotyper {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		STref_dir=STref_dir,
		recaled_bam=BQSR.recaled_bam,
		recaled_bam_index=BQSR.recaled_bam_index,
		dbsnp_dir=dbsnp_dir,
		dbsnp=dbsnp,
		sample=sample,
		STdocker=STdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Hardfiltration.Hardfiltration as Hardfiltration {
		input:
		fasta=fasta,
		STref_dir=STref_dir,
		vcf_file=Haplotyper.vcf,
		vcf_index=Haplotyper.vcf_idx,
		sample=sample,
		GATKdocker=GATKdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	}

